<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU" sourcelanguage="en">
<context>
    <name>CertUpdate</name>
    <message>
        <source>update not allowed!</source>
        <translation>oбновление не разрешено!</translation>
    </message>
    <message>
        <source>Check internet connection</source>
        <translation>Проверте подключение к интернету</translation>
    </message>
    <message>
        <source>Server sai vale arvu baite, samm: %1</source>
        <translation>Сервер получил неправильное количество байтов, шаг: %1</translation>
    </message>
    <message>
        <source>Serveri töös tekkisid vead, samm: %1</source>
        <translation>В работе сервера произошла ошибка, шаг: %1</translation>
    </message>
    <message>
        <source>Kaardi vastuse parsimisel tekkis viga, samm: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sertifitseerimiskeskus ei vasta, samm: %1</source>
        <translation>Центр сертифицирования не отвечает, шаг: %1</translation>
    </message>
</context>
<context>
    <name>DiagnosticsDialog</name>
    <message>
        <source>ID-card utility version:</source>
        <translation>Версия:</translation>
    </message>
    <message>
        <source>OS:</source>
        <translation>Оп. система:</translation>
    </message>
    <message>
        <source>Library paths:</source>
        <translation>Поиск по тэгам:</translation>
    </message>
    <message>
        <source>Libraries</source>
        <translation>Тэги</translation>
    </message>
    <message>
        <source>Smart Card service status: </source>
        <translation>Статус Smart Card сервиса: </translation>
    </message>
    <message>
        <source>PCSC service status: </source>
        <translation>Статус PCSC сервиса: </translation>
    </message>
    <message>
        <source>Running</source>
        <translation>Работает</translation>
    </message>
    <message>
        <source>Not running</source>
        <translation>Не работает</translation>
    </message>
    <message>
        <source>Card readers</source>
        <translation>Считыватели карт</translation>
    </message>
    <message>
        <source>%1 - failed to get version info</source>
        <translation>%1 - ошибка при чтении версии</translation>
    </message>
    <message>
        <source>ID - %1</source>
        <translation>ID - %1</translation>
    </message>
    <message>
        <source>Error reading card data:</source>
        <translation>Ошибка при чтении с карты:</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>Текстовые файлы (*.txt)</translation>
    </message>
    <message>
        <source>Error occurred</source>
        <translation>Возникла ошибка</translation>
    </message>
    <message>
        <source>Failed write to file!</source>
        <translation>Запись файла неудачна!</translation>
    </message>
    <message>
        <source>Diagnostics</source>
        <translation>Диагностика</translation>
    </message>
</context>
<context>
    <name>JsExtender</name>
    <message>
        <source> - %1 (active)</source>
        <translation> - %1 (активно)</translation>
    </message>
    <message>
        <source> - %1 (not active)</source>
        <translation> - %1 (неактивно)</translation>
    </message>
    <message>
        <source>Save picture</source>
        <translation>Cохранить картинку</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;TIFF (*.tif *.tiff);;24-bit Bitmap (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;TIFF (*.tif *.tiff);;24-bit Bitmap (*.bmp)</translation>
    </message>
    <message>
        <source>Certificate update</source>
        <translation>Обновление сертификата</translation>
    </message>
    <message>
        <source>Certificate update failed: %1</source>
        <translation>Неудачное обновление сертификата: %1</translation>
    </message>
    <message>
        <source>Certificate update failed:&lt;br /&gt;%1</source>
        <translation>Неудачное обновление сертификата:&lt;br /&gt;%1</translation>
    </message>
    <message>
        <source>For updating certificates please close all programs which are interacting with smartcard (qdigidocclient, qdigidoccrypto, Firefox, Safari, Internet Explorer...)&lt;br /&gt;After updating certificates it will no longer be possible to decrypt documents that were encrypted with the old certificate.&lt;br /&gt;Do you want to continue?</source>
        <translation>Для обновления сертификата пожалуйста закройте все приложения, которые используют ID-карту (Клиент, Crypto, Firefox, Safari, Internet Explorer...)&lt;br /&gt;После обновления сертификатов шифровка документов будет невозможна!&lt;br /&gt;Хотите продолжить?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>ID-card utility</source>
        <translation>Oбсуживание ID-карты</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Save PIN1 for specified period in minutes
0 - always ask</source>
        <translation>Сохранять PIN1 на обозначенный период в минутах
0 - всегда спрашивать</translation>
    </message>
    <message>
        <source>Check updates</source>
        <translation>Проверить на обновления</translation>
    </message>
    <message>
        <source>Update automatically</source>
        <translation>Обновлять автоматически</translation>
    </message>
    <message>
        <source>Once a day</source>
        <translation>Раз в день</translation>
    </message>
    <message>
        <source>Once a week</source>
        <translation>Раз в неделю</translation>
    </message>
    <message>
        <source>Once a month</source>
        <translation>Раз в месяц</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Никогда</translation>
    </message>
</context>
</TS>
